@@ -157,9 +157,12 @@ def extract_all(session_path, save=False, bpod_trials=False, settings=False, ext
         bpod_trials = raw.load_data(session_path)
     if not settings:
         settings = raw.load_settings(session_path)
-    if settings is None or settings['IBLRIG_VERSION_TAG'] == '':
+    if settings is None:
         settings = {'IBLRIG_VERSION_TAG': '100.0.0'}
 
+    if settings['IBLRIG_VERSION_TAG'] == '':
+        settings['IBLRIG_VERSION_TAG'] = '100.0.0'
+
     base = [GoCueTriggerTimes]
     # Version check
     if parse_version(settings['IBLRIG_VERSION_TAG']) >= parse_version('5.0.0'):
