@@ -10,7 +10,7 @@ import json
 
 from graphviz import Digraph
 
-from ibllib.misc import version
+import ibllib
 from ibllib.oneibl import data_handlers
 import one.params
 from one.api import ONE
@@ -30,7 +30,7 @@ class Task(abc.ABC):
     outputs = None  # place holder for a list of Path containing output files
     time_elapsed_secs = None
     time_out_secs = 3600 * 2  # time-out after which a task is considered dead
-    version = version.ibllib()
+    version = ibllib.__version__
     signature = {'input_files': [], 'output_files': []}  # list of tuples (filename, collection, required_flag)
     force = False  # whether or not to re-download missing input files on local server if not present
 
@@ -100,7 +100,7 @@ class Task(abc.ABC):
         _logger.info(f"Starting job {self.__class__}")
         if self.machine:
             _logger.info(f"Running on machine: {self.machine}")
-        _logger.info(f"running ibllib version {version.ibllib()}")
+        _logger.info(f"running ibllib version {ibllib.__version__}")
         # setup
         start_time = time.time()
         try:
@@ -193,7 +193,7 @@ class Task(abc.ABC):
         :param overwrite: (bool) if the output already exists,
         :return: out_files: files to be registered. Could be a list of files (pathlib.Path),
         a single file (pathlib.Path) an empty list [] or None.
-        Whithin the pipeline, there is a distinction between a job that returns an empty list
+        Within the pipeline, there is a distinction between a job that returns an empty list
          and a job that returns None. If the function returns None, the job will be labeled as
           "empty" status in the database, otherwise, the job has an expected behaviour of not
           returning any dataset.
@@ -524,9 +524,10 @@ def run_alyx_task(tdict=None, session_path=None, one=None, job_deck=None,
         # if any of the parent tasks is not complete, throw a warning
         if any(map(lambda s: s not in ['Complete', 'Incomplete'], parent_statuses)):
             _logger.warning(f"{tdict['name']} has unmet dependencies")
-            # if parents are just waiting, don't do anything, but if they have a failed status
-            # set the current task status to Held
-            if any(map(lambda s: s in ['Errored', 'Held', 'Empty'], parent_statuses)):
+            # if parents are waiting or failed, set the current task status to Held
+            # once the parents ran, the descendent tasks will be set from Held to Waiting (see below)
+            if any(map(lambda s: s in ['Errored', 'Held', 'Empty', 'Waiting', 'Started', 'Abandoned'],
+                       parent_statuses)):
                 tdict = one.alyx.rest('tasks', 'partial_update', id=tdict['id'],
                                       data={'status': 'Held'})
             return tdict, registered_dsets
