@@ -61,12 +61,23 @@ _log = logging.getLogger('ibllib')
 
 class TaskQC(base.QC):
     """A class for computing task QC metrics"""
-    criteria = {"PASS": 0.99, "WARNING": 0.95, "FAIL": 0}
-    fcns_value2status = {'default': lambda x: TaskQC._thresholding(x),
-                         '_task_stimFreeze_delays': lambda x: - 1,
-                         '_task_response_stimFreeze_delays': lambda x: -1,
-                         '_task_passed_trial_checks': lambda x: -1,
-                         '_task_iti_delays': lambda x: -1}
+
+    criteria = dict()
+    criteria['default'] = {"PASS": 0.99, "WARNING": 0.90, "FAIL": 0}  # Note: WARNING was 0.95 prior to Aug 2022
+    criteria['_task_stimOff_itiIn_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_positive_feedback_stimOff_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_negative_feedback_stimOff_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_wheel_move_during_closed_loop'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_response_stimFreeze_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_detected_wheel_moves'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_trial_length'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_goCue_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_errorCue_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_stimOn_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_stimOff_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_stimFreeze_delays'] = {"PASS": 0.99, "WARNING": 0}
+    criteria['_task_iti_delays'] = {"NOT_SET": 0}
+    criteria['_task_passed_trial_checks'] = {"NOT_SET": 0}
 
     @staticmethod
     def _thresholding(qc_value, thresholds=None):
@@ -75,18 +86,25 @@ class TaskQC(base.QC):
         :param qc_value: proportion of passing qcs, between 0 and 1
         :param thresholds: dictionary with keys 'PASS', 'WARNING', 'FAIL'
          (cf. TaskQC.criteria attribute)
-        :return: int where -1: NOT_SET, 0: FAIL, 1: WARNING, 2: PASS
+        :return: int where -1: NOT_SET, 0: PASS, 1: WARNING, 2: FAIL
         """
         MAX_BOUND, MIN_BOUND = (1, 0)
         if not thresholds:
-            thresholds = TaskQC.criteria.copy()
+            thresholds = TaskQC.criteria['default'].copy()
         if qc_value is None or np.isnan(qc_value):
             return int(-1)
         elif (qc_value > MAX_BOUND) or (qc_value < MIN_BOUND):
             raise ValueError("Values out of bound")
-        else:
-            passed = qc_value >= np.fromiter(thresholds.values(), dtype=float)
-            return int(np.argmax(passed))
+        if 'PASS' in thresholds.keys() and qc_value >= thresholds['PASS']:
+            return 0
+        if 'WARNING' in thresholds.keys() and qc_value >= thresholds['WARNING']:
+            return 1
+        if 'FAIL' in thresholds and qc_value >= thresholds['FAIL']:
+            return 2
+        if 'NOT_SET' in thresholds and qc_value >= thresholds['NOT_SET']:
+            return -1
+        # if None of this applies, return 'NOT_SET'
+        return -1
 
     def __init__(self, session_path_or_eid, **kwargs):
         """
@@ -163,16 +181,15 @@ class TaskQC(base.QC):
         :return: Overall session QC outcome as a string
         :return: A dict of QC tests and their outcomes
         """
-        v2status_fcns = TaskQC.fcns_value2status  # the need to have this as a parameter may arise
         indices = np.zeros(len(results), dtype=int)
         for i, k in enumerate(results):
-            if k in v2status_fcns:
-                indices[i] = v2status_fcns[k](results[k])
+            if k in TaskQC.criteria.keys():
+                indices[i] = TaskQC._thresholding(results[k], thresholds=TaskQC.criteria[k])
             else:
-                indices[i] = v2status_fcns['default'](results[k])
+                indices[i] = TaskQC._thresholding(results[k], thresholds=TaskQC.criteria['default'])
 
         def key_map(x):
-            return 'NOT_SET' if x < 0 else list(TaskQC.criteria.keys())[x]
+            return 'NOT_SET' if x < 0 else list(TaskQC.criteria['default'].keys())[x]
         # Criteria map is in order of severity so the max index is our overall QC outcome
         session_outcome = key_map(max(indices))
         outcomes = dict(zip(results.keys(), map(key_map, indices)))
