@@ -399,6 +399,9 @@ class TestVideo(unittest.TestCase):
     @classmethod
     def setUpClass(cls) -> None:
         cls.one = ONE(**TEST_DB)
+        if 'public' in cls.one.alyx._par.HTTP_DATA_SERVER:
+            cls.one.alyx._par = cls.one.alyx._par.set(
+                'HTTP_DATA_SERVER', cls.one.alyx._par.HTTP_DATA_SERVER.rsplit('/', 1)[0])
 
     def setUp(self) -> None:
         self.eid = '8dd0fcb0-1151-4c97-ae35-2e2421695ad7'
